<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">Tietoja</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Tekijät</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Kevyt WebKit-pohjainen verkkoselain</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Kielet</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Kielet mielekkyysjärjestyksessä:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Siirrä &amp;ylös</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Siirrä &amp;alas</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Lisää...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation type="unfinished">Sääntö</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Lisää kirjanmerkki</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Kirjoita nimi kirjanmerkille ja valitse minne se lisätään.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Lisää kansio</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Poista</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Avaa uudessa välilehdessä</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Muokkaa nimeä</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Muokkaa osoitetta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Uusi kansio</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Kirjanmerkit</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Lisää kansio</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Kirjanmerkkipalkki</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Kirjanmerkkivalikko</translation>
    </message>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Virhe kirjanmerkin latauksessa rivillä %1, sarakkeella %2
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Työkalurivin kirjanmerkit</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Valikko</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Avaa tiedosto</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Tuotu %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Tallenna tiedosto</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation></translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Vie virhe</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>virhe kirjanmerkkien tallennuksessa</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Poista kirjanmerkki</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Lisää kirjanmerkki</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">Nimen muutos</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">Osoitteen muutos</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Virhe ladattaessa html kirjanmerkkejä: %1
</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation type="unfinished">Nimen muutos</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation type="unfinished">Osoitteen muutos</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Avaa välilehtiin</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Osoite</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Kirjanmerkkipalkki</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Avaa uudessa &amp;välilehdessä</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Lisää kirjanmerkki...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Lisää kansio...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Kirjanmerkit</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete"> (Muuta: %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>%1 ikkunaa ja %2 välilehteä ovat avoinna
Haluatko lopettaa siitä huolimatta?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Palautus epäonnistui</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Tallennettua istuntoa ei palautettu koska Arora kaatui yrittäessään palauttaa tätä istuntoa.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Tiedosto</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Uusi ikkuna</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Avaa tiedosto...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Avaa &amp;sijainti...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Tallenna nimellä...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Tuo kirjanmerkkejä...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Vie kirjanmerkkejä...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>T&amp;ulostuksen esikatselu...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Tulosta...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Yksityinen &amp;selailu...</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Sulje ikkuna</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Lopeta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Kumoa</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Tee uudelleen</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Leikka&amp;a</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopioi</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Liitä</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Etsi</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Etsi seuraav&amp;a</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Etsi e&amp;dellinen</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">Asetu&amp;kset...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Näytä</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Näytä valikkopalkki</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;Päivitä sivu</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Pysäytä</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Suurenna</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>&amp;Palauta</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Pienennä</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Suurenna vain &amp;tekstiä</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>Sivun l&amp;ähdekoodi</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Koko näyttö</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>Sivuhi&amp;storia</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Edellinen</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Aloitussivu</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Palauta edellinen istunto</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Kirjanmerkit</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Näytä kaikki kirjanmerkit...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Lisää kirjanmerkki...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>LIsää kansio...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Ikkuna</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Työkalut</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>Verkko&amp;haku</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Poista yksityisyystietoja</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation></translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">Näytä &amp;verkkomonitori</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Käytä Web &amp;Inspectoria</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ohje</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Vaihda ohjelman kieli</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Tietoja &amp;Qt:sta</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>Tietoja &amp;%1:sta</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navigointipalkki</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Näytä tilarivi</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Piilota tilarivi</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Näytä työkalupalkki</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Piilota työkalupalkki</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Näytä kirjanmerkkipalkki</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Piilota kirjanmerkkipalkki</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation></translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Avaa web-tiedostoja</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Web-tiedostot (*.html *.htm *.svg *.png *.gif *.svgz);;Kaikki tiedostot (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Tulosta dokumentti</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Oletko varma että haluat sulkea yksityisen selailun?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Kun yksityinen selailu on päällä, jotkut toiminnot liittyen yksityisyyteesi ovat pois päältä:&lt;ul&gt;&lt;li&gt; Verkkosivuja ei lisätä sivuhistoriaan.&lt;/li&gt;&lt;li&gt;Tiedostot poistetaan automaattisesti Lataukset ikkunasta&lt;/li&gt;&lt;li&gt;Uusia evästeitä ei lisätä, eikä nykyisiin evästeisiin pääse käsiksi.&lt;/li&gt;&lt;li&gt;Sivujen kuvakkeita ei tallenneta, istuntoja ei tallenneta.&lt;/li&gt;&lt;li&gt;Hakuja ei lisätä ponnahdusikkuna-valikkoon hakulaatikossa.&lt;/li&gt;&lt;/ul&gt;Kunnes suljet ikkunan, vois yhä napsauttaa Edellinen ja Seuraava painikkeita palataksesi verkkosivulle minkä olet avannut.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Oletko varma että haluat sulkea ikkunan? Siinä on %1 välilehteä avoinna</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation></translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Web Inspector toimii oikein vain sivuilla jotka on päivitetty sen käyttöön ottamisen jälkeen.
Haluatko päivittää kaikki sivut?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Lopeta nykyisen sivun lataaminen</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Päivitä nykyinen sivu</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Poista yksityisyystietoja</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Poista seuraavat tiedot:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>&amp;Sivuhistoria</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>&amp;Lataukset</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>&amp;Haut</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Evästeet</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>&amp;Välimuisti</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>Verkkosivujen &amp;kuvakkeet</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Poista &amp;yksityisyystiedot</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Peruuta</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Verkkosivu</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Sääntö</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Salli</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Estä</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Salli istunnon ajaksi</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Verkkosivu</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Polku</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Turvallinen</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Vanhenee</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Sisältö</translation>
    </message>
    <message>
        <source>true</source>
        <translation>tosi</translation>
    </message>
    <message>
        <source>false</source>
        <translation>epätosi</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Evästeet</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Poista &amp;kaikki evästeet</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Evästeiden poikkeukset</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Uusi poikkeus</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation></translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Estä</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Salli istunnon ajaksi</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Salli</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Poikkeukset</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Poista &amp;kaikki</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 tiedostoa</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Lomake</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Kuvake</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Tiedostonimi</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Yritä uudestaan</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pysäytä</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Tallenna tiedosto</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Lataus keskeytetty: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Virhe avattaessa tiedostoa: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Virhe tallennettaessa: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Verkon virhe: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">sekunnit</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>- %n minuutti jäljellä</numerusform>
            <numerusform>- %n minuuttia jäljellä</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>- %n sekunti jäljellä</numerusform>
            <numerusform>- %n sekuntia jäljellä</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1/%2 (%3/sek) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1/%2 - Pysäytetty</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">tavua</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="obsolete">kt</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="obsolete">Mt</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1/%2 (%3/sek) %4</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Käynnissä on %1 latausta
Haluatko lopettaa siitä huolimatta?</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n Lataus</numerusform>
            <numerusform>%n Latausta</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>%n minuutti jäljellä</numerusform>
            <numerusform>%n minuuttia jäljellä</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>%n sekunti jäljellä</numerusform>
            <numerusform>%n sekuntia jäljellä</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>tavua</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kt</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>Mt</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Avaa</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopio</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Poista</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Poista &amp;kaikki</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Näytä koko historia</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Tyhjennä historia...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Poista historia</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Haluatko poistaa historian?</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Osoite</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Aiemmin tänään</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n kohde</numerusform>
            <numerusform>%n kohdetta</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Yhtään käännöstä ei ole asennettu.</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Valitse kieli</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Voit käyttää eri kieltä&lt;br&gt;kuin käyttöjärjestelmän oletus.&lt;/p&gt;&lt;p&gt;Ole hyvä ja valitse kieli mitä käytetään&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Anna käyttäjätunnus ja salasana palvelimelle %2, sivuston viesti &quot;%1&quot;&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Yhdistä välityspalvelimeen &quot;%1&quot; käyttäen:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation> - SSL Virheet</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;SSL virheet:&lt;br/&gt;&lt;br/&gt;&lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Haluatko sivuuttaa nämä virheet?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certifactes:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="obsolete">&lt;qt&gt;Varmenteet:&lt;br/&gt;%1&lt;br/&gt;Hyväksytkö kaikki nämä varmenteet?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Nimi</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Arvo</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Verkkomonitori</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Verkon pyynnöt</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Pyynnön otsakkeet</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Vastauksen otsakkeet</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Poista</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Poista &amp;kaikki pyynnöt</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation type="unfinished">Avaa tiedosto</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Nimi</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Tunnistautuminen vaaditaan</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation></translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Käyttäjätunnus:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Ei löytynyt</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Välityspalvelimen varmennus</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Yhdistä välityspalvelimeen</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Käyttäjätunnus:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Tiedosto ei ole XBEL versio 1.0 tiedosto.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Tuntematon otsikko</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Uudelleenohjaus: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Menetelmä</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Osoite</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Vastaus</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Pituus</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Sisältötyyppi</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Tietoja</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Lomake</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Haku</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Käynnistettäessä:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Näytä kotisivuni</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Näytä tyhjä sivu</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Palauta ikkunat ja välilehdet viime kerralta</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Kotisivu:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Käytä avointa sivua</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Poista historia:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Päivän jälkeen</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Viikon jälkeen</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Kahden viikon jälkeen</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Kuukauden jälkeen</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Vuoden jälkeen</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Käsin</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Lopetettaessa</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Lataukset</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Kysy kansiota joka kerta</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Käytä kansiota:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Ulkoasu</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Oletuskirjasinlaji:</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Valitse...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Tasalevyinen kirjasin:</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Kieli, jolla sivut näytetään:</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Yksityisyys</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Sisältö</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Estä ponnahdusikkunat</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Käytä liitännäisiä</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Käytä Javascriptiä</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Näytä kuvat</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Evästeet</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Hyväksy evästeet:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Aina</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Ei ikinä</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Ainoastaan sivuilta joille menet</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Poikkeukset...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Säilytä evästeet:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>kunnes ne vanhenevat</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>kunnes selain suljetaan</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Korkeintaan 90 päivää</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Evästeet...</translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Välilehdet</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Valitse välilehdet ja ikkunat silloin kun ne luodaan</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">Varoita, kun yritän sulkea useita välilehtiä samanaikaisesti</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Näytä ainoastaan yksi sulkupainike sen sijaan, että jokaisella välilehdella olisi oma sulkupainike</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Avautuvat linkit</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Avaa linkit jotka haluavat avautua uuteen ikkunaan:</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>Uuteen ikkunaan</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>Uuteen valittuun välilehteen nykyisessä ikkunassa</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>Uuteen välilehteen nykyisessä ikkunassa</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>Nykyiseen välilehteen</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Avaa linkit:</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Välityspalvelin</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Käytä välityspalvelinta</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tyyppi:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation></translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (turvallinen)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (läpinäkyvä)</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Verkko-osoite:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Portti:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Käyttäjätunnus:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Kehittyneet</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Tyylitiedosto:</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Ladataan...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Muokkaa</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Etsi</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Katso</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">&amp;Rivitys</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Sivun lähdekoodi</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Näytä välilehtipalkki</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Piilota välilehtipalkki</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Kahdenna välilehti</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Sulje välilehti</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Sulje &amp;muut välilehdet</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Päiviä välilehti</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Päivitä kaikki välilehdet</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>Untitled</source>
        <translation>Nimetön</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>Tallennetut välilehdet</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Oletko varma että haluat sulkea tämän sivun?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Olet muokannut tätä sivua ja jos se suljetaan menetät muokkaukset.
Haluatko varmasti sulkea tämän sivun?
</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Ladataan...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Ladataan %1 % (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Ladattu</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Lataus epäonnistui</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Näytä seuraava välilehti</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Näytä edellinen välilehti</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation></translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Äskettäin suljetut välilehdet</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Uusi &amp;välilehti</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Sulje välilehti</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Lisää kaikki välilehdet kirjanmerkkeihin</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>Ei äskeisiä hakuja</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Äskeiset haut</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation type="unfinished">Tyhjennä äskeiset haut</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Ehdotukset</translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Virhe ladattaessa sivua: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Yhdistettäessä: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Tarkista osoite virheiden varalta, esim. &quot;&lt;b&gt;ww&lt;/b&gt;.arora-browser.org&quot; oikean muodon sijaan &quot;&lt;b&gt;www&lt;/b&gt;.arora-browser.org&quot;</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Jos osoite on oikea, tarkista yhteytesi.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Jos tietokoneesi tai verkkosi on suojattu palomuurilla tai välityspalvelimella, tarkista että selaimella on pääsy verkkoon.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Avaa uudessa &amp;ikkunassa</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Avaa uudessa &amp;välilehdessä</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Tallenna osoit&amp;e</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>&amp;Lisää tämä osoite kirjanmerkkeihin</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Kopioi osoite</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Avaa kuva uudessa &amp;ikkunassa</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Avaa kuva uudessa &amp;välilehdessä</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Tallenna kuva</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Kopioi kuva</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>K&amp;opioi kuvan osoite</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Ladataan...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Ei löytynyt</translation>
    </message>
</context>
</TS>
